<?php
class InstruktorDB
{
    private $spojeni;
    private $databaze = "autoskola";
    private $jmeno = "root";
    private $heslo = "";

    public function __construct()
    {
        $this->spojeni = new PDO("mysql:dbname=$this->databaze;charset=UTF8;host=localhost",
            $this->jmeno, $this->heslo);
    }

    public function overeniInstruktora($email, $heslo)
    {
        $dotaz = "SELECT * FROM instruktori WHERE email=:email LIMIT 1";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":email", $email);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Instruktor");
        $instruktor = $sql->fetch();
        if (password_verify($heslo, $instruktor->heslo)) {
            return $instruktor;
        } else {
            return false;
        }
    }

    public function zaregistrujInstruktora($instruktor)
    {
        $dotaz = "INSERT INTO instruktori (id_instruktora, jmeno, prijmeni, tel_cislo, email, heslo, prava) 
                   VALUES (NULL, :jmeno, :prijmeni, :tel_cislo, :email, :heslo,:prava
                   )";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":jmeno", $instruktor->jmeno);
        $sql->bindParam(":prijmeni", $instruktor->prijmeni);
        $sql->bindParam(":tel_cislo", $instruktor->tel_cislo);
        $sql->bindParam(":email", $instruktor->email);
        $sql->bindParam(":heslo", $instruktor->heslo);
        $sql->bindParam(":prava", $instruktor->prava);
        if ($sql->execute()) {
            return $this->spojeni->lastInsertId(); //vrátí true, metoda lastInsertId vrací id právě vloženého záznamu
        } else {
            return false;
        }
    }

    public function nactiInstruktory($razeni = "id_instruktora ASC")
    {
        $moznosti_razeni = array("id_instruktora ASC", "jmeno", "prijmeni");

        if (!in_array(strtolower($razeni), $moznosti_razeni)) {
            $razeni = "id_instruktora ASC";
        }

        $dotaz = "SELECT * FROM instruktori ORDER BY $razeni";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Instruktor");
        return $sql->fetchAll();
    }

    public function editaceInstruktora($instruktor)
    {
        $dotaz = "UPDATE instruktori SET jmeno= :jmeno, prijmeni= :prijmeni, tel_cislo= :tel_cislo, 
                       email= :email, heslo= :heslo, prava= :prava 
                  WHERE id_instruktora= :id_instruktora
                ";

        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_instruktora", $instruktor->id_instruktora);
        $sql->bindParam(":jmeno", $instruktor->jmeno);
        $sql->bindParam(":prijmeni", $instruktor->prijmeni);
        $sql->bindParam(":tel_cislo", $instruktor->tel_cislo);
        $sql->bindParam(":email", $instruktor->email);
        $sql->bindParam(":heslo", $instruktor->heslo);
        $sql->bindParam(":prava", $instruktor->prava);
        $sql->execute();
    }

    public function smazInstruktora($id_instruktora)
    {
        $dotaz = "DELETE FROM instruktori WHERE id_instruktora= :id_instruktora";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_instruktora", $id_instruktora);
        $sql->execute();
    }

    public function editujOsUdajeInstruktora($instruktor)
    {
        $dotaz = "UPDATE instruktori SET jmeno= :jmeno, prijmeni= :prijmeni, tel_cislo= :tel_cislo, 
                 email= :email  WHERE id_instruktora= :id_instruktora";

        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":jmeno", $instruktor->jmeno);
        $sql->bindParam(":prijmeni", $instruktor->prijmeni);
        $sql->bindParam(":tel_cislo", $instruktor->tel_cislo);
        $sql->bindParam(":email", $instruktor->email);
        $sql->bindParam("id_instruktora", $_SESSION["id_instruktora"]);
        $sql->execute();
    }

    public function vyberHesloInstruktora($heslo): bool
    {
        $dotaz = "SELECT heslo FROM instruktori WHERE id_instruktora = :id_instruktor";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_instruktor", $_SESSION["id_instruktora"]);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Instruktor");
        $instruktor = $sql->fetch();
        if (password_verify($heslo, $instruktor->heslo)) {
            return true;
        } else {
            return false;
        }
    }

    public function zmenHeslo($heslo)
    {
        $dotaz = "UPDATE instruktori SET heslo = :heslo WHERE id_instruktora = :id_instruktora";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":heslo", $heslo);
        $sql->bindParam(":id_instruktora", $_SESSION["id_instruktora"]);
        $sql->execute();
    }

    public function nactiInstruktora($id_instruktora)
    {
        $dotaz = "SELECT * FROM instruktori WHERE id_instruktora=:id_instruktora";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_instruktora", $id_instruktora);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Instruktor");
        return $sql->fetch();
    }

    public function overEmail($email)
    {
        $dotaz = "SELECT COUNT(*) FROM zaci1 WHERE email=:email LIMIT 1";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":email", $email);
        if($sql->execute())
        {
            return true;
        }
        else
        {
            return false;
        }
    }
}