<?php

class RezervaceDB
{
    private $spojeni;
    private $databaze = "autoskola";
    private $jmeno = "root";
    private $heslo = "";

    public function __construct()
    {
        $this->spojeni = new PDO("mysql:dbname=$this->databaze;charset=UTF8;host=localhost",
            $this->jmeno, $this->heslo);
    }

    public function ulozeniRezervace($rezervace)
    {
        $dotaz = "INSERT INTO rezervace (id_jizdy, datum, cas, misto, poznamka, id_instruktor, skupina_opravneni) 
                VALUES (NULL,:datum,:cas,:misto,:poznamka, :id_instruktor, :skupina_opravneni 
                        )";

        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":datum", $rezervace->datum);
        $sql->bindParam(":cas", $rezervace->cas);
        $sql->bindParam(":misto", $rezervace->misto);
        $sql->bindParam(":poznamka", $rezervace->poznamka);
        $sql->bindParam(":id_instruktor", $_SESSION["id_instruktora"]);
        $sql->bindParam("skupina_opravneni", $rezervace->skupina_opravneni);

        if ($sql->execute()) {
            return $this->spojeni->lastInsertId();
        } else {
            return false;
        }
    }

    public function nactiRezervace($razeni = "datum ASC")
    {
        $moznosti_razeni = array("datum ASC");

        if (!in_array(strtolower($razeni), $moznosti_razeni))
        {
            $razeni = "datum ASC";
        }

        $dotaz = "SELECT jmeno, prijmeni,tel_cislo, id_jizdy, id_instruktor,datum, cas, misto, poznamka, 
       rezervace.skupina_opravneni FROM rezervace, instruktori WHERE rezervace.id_instruktor = instruktori.id_instruktora 
        AND id_zak IS NULL AND skupina_opravneni = :skupina_opravneni ORDER BY $razeni";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":skupina_opravneni", $_SESSION["skupina_opravneni"]);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
        return $sql->fetchAll();
    }

public function nactiRezervaci($id)
{
$dotaz = "SELECT * FROM rezervace WHERE id_jizdy= :id_jizdy";
$sql = $this->spojeni->prepare($dotaz);
$sql->bindParam(":id_jizdy", $id);
$sql->execute();
$sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
return $sql->fetch(); //vrátí objekt
}

    public function PriradIdZakaRezervaci($id_jizdy)
    {
$dotaz= "UPDATE rezervace SET id_zak = :id_zak WHERE id_jizdy = :id_jizdy";
$sql = $this->spojeni->prepare($dotaz);
$sql->bindParam(":id_zak", $_SESSION["id_zaka"] );
$sql->bindParam(":id_jizdy", $id_jizdy);
$sql->execute();
    }

    public function vyberRezervaceZaka()
    {
        $dotaz= "SELECT * FROM rezervace WHERE id_zak = :id_zak";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zak", $_SESSION["id_zaka"]);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
        return $sql->fetchAll();
    }

    public function odebratIdZaka($id_jizdy)
    {
        $dotaz = "UPDATE rezervace SET id_zak = NULL WHERE id_jizdy = :id_jizdy";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_jizdy", $id_jizdy);
        $sql->execute();
    }

public function  vypsatRezervaceInstruktoraBezIdZaka()
{
    $dotaz = "SELECT * FROM rezervace WHERE id_zak IS NULL AND id_instruktor = :id_instruktor ";
    $sql = $this->spojeni->prepare($dotaz);
    $sql->bindParam(":id_instruktor", $_SESSION['id_instruktora']);
    $sql->execute();
    $sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
    return $sql->fetchAll();
}

public  function vypsatRezervaceInstruktoraSIdZaka()
{
    $dotaz = "SELECT * FROM rezervace WHERE id_zak IS NOT NULL AND id_instruktor = :id_instruktor";
    $sql = $this->spojeni->prepare($dotaz);
    $sql->bindParam(":id_instruktor", $_SESSION['id_instruktora']);
    $sql->execute();
    $sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
    return $sql->fetchAll();
}

public function smazRezervaci($id_jizdy)
{
    $dotaz = "DELETE FROM rezervace WHERE id_jizdy = :id_jizdy";
    $sql = $this->spojeni->prepare($dotaz);
    $sql->bindParam(":id_jizdy", $id_jizdy);
    $sql->execute();
}

public function smazatNevybranouRezervaci()
{
    $dotaz = "DELETE FROM rezervace WHERE id_zak IS NULL AND datum <= CURRENT_DATE() AND cas <= CURRENT_TIME";
    $sql = $this->spojeni->prepare($dotaz);
    $sql->execute();
}

public function vyberRezervaciProInstruktora()
{
    $dotaz = "SELECT jmeno, prijmeni,tel_cislo, id_jizdy, id_instruktor, id_zak,datum, cas, misto, poznamka, 
       rezervace.skupina_opravneni FROM rezervace, zaci1 WHERE rezervace.id_zak = zaci1.id_zaka
       AND id_zak IS NOT NULL AND id_instruktor = :id_instruktor";
    $sql = $this->spojeni->prepare($dotaz);
    $sql->bindParam(":id_instruktor", $_SESSION['id_instruktora']);
    $sql->execute();
    $sql->setFetchMode(PDO::FETCH_CLASS, "rezervace");
    return $sql->fetchAll();
}

    public function vyberRezervaciProZaka()
    {
        $dotaz = "SELECT jmeno, prijmeni,tel_cislo, id_jizdy, id_instruktor,datum, cas, misto, poznamka, 
       rezervace.skupina_opravneni FROM rezervace, instruktori WHERE rezervace.id_instruktor = instruktori.id_instruktora
       AND id_zak IS NOT NULL AND id_zak = :id_zak";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zak", $_SESSION['id_zaka']);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "rezervace");
        return $sql->fetchAll();
    }

    public function najdiRezervace($text, $razeni = "datum ASC")
    {
        $moznosti_razeni = array("id", "nadpis", "datum", "datum ASC");
        if (!in_array(strtolower($razeni), $moznosti_razeni))
        {
            $razeni = "datum ASC";
        }
        $text = "%".mb_strtolower($text, "UTF-8")."%";
        $dotaz = "SELECT rezervace.id_jizdy, rezervace.datum, rezervace.cas, rezervace.misto, rezervace.poznamka, 
        rezervace.skupina_opravneni, instruktori.jmeno, instruktori.prijmeni, instruktori.tel_cislo
         FROM rezervace JOIN instruktori ON rezervace.id_instruktor = instruktori.id_instruktora
         WHERE skupina_opravneni = :skupina_opravneni AND id_zak IS NULL AND (lower(datum) LIKE :text OR lower(cas) LIKE :text OR lower(misto) 
        LIKE :text OR lower(poznamka) LIKE :text OR lower(instruktori.jmeno) LIKE :text OR lower(instruktori.prijmeni) 
        LIKE :text OR lower(instruktori.tel_cislo) LIKE :text) ORDER BY $razeni";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":text", $text);
        $sql->bindParam(":skupina_opravneni", $_SESSION['skupina_opravneni']);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Rezervace");
        return $sql->fetchAll();
    }
}