<?php

class ZakDB
{

    private $spojeni;
    private $databaze = "autoskola";
    private $jmeno = "root";
    private $heslo = "";

    public function __construct()
    {
        $this->spojeni = new PDO("mysql:dbname=$this->databaze;charset=UTF8;host=localhost",
        $this->jmeno, $this->heslo);
    }

    public function overeniZaka($email, $heslo)
    {
        $dotaz = "SELECT * FROM zaci1 WHERE email=:email LIMIT 1";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":email", $email);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Zak");
        $zak = $sql->fetch();
        if(password_verify($heslo,$zak->heslo))
        {
            return $zak;
        }
        else
        {
            return false;
        }
    }

    public function nactiZaky($razeni = "id_zaka ASC") //řazení podle datumu sestupně
    {
        $moznosti_razeni = array("id_zaka ASC");

        if (!in_array(strtolower($razeni), $moznosti_razeni))
        {
            $razeni = "id_zaka ASC";
        }

        $dotaz = "SELECT * FROM zaci1 ORDER BY $razeni";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Zak");
        return $sql->fetchAll();
    }

    public function nactiZaka($id)
    {
        $dotaz = "SELECT * FROM zaci1 WHERE id_zaka=:id";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id", $id);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Zak");
        return $sql->fetch();
    }

    public function editaceZaka($zak)
    {
        $dotaz = "UPDATE zaci1 SET jmeno= :jmeno, prijmeni= :prijmeni, datum_narozeni= :datum_narozeni, 
                 tel_cislo= :tel_cislo, email= :email, heslo= :heslo, skupina_opravneni= :skupina_opravneni, 
                 odjeto_jizd= :odjeto_jizd  WHERE id_zaka= :id_zaka
                ";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zaka", $zak->id_zaka);
        $sql->bindParam(":jmeno", $zak->jmeno);
        $sql->bindParam(":prijmeni", $zak->prijmeni);
        $sql->bindParam(":datum_narozeni", $zak->datum_narozeni);
        $sql->bindParam(":tel_cislo", $zak->tel_cislo);
        $sql->bindParam(":email", $zak->email);
        $sql->bindParam(":heslo", $zak->heslo);
        $sql->bindParam(":skupina_opravneni", $zak->skupina_opravneni);
        $sql->bindParam(":odjeto_jizd", $zak->odjeto_jizd);
       $sql->execute();
    }

    public function zaregistrujZaka($zak)
    {
        $dotaz="INSERT INTO zaci1 (id_zaka, jmeno, prijmeni, datum_narozeni, tel_cislo, email, heslo, 
                   skupina_opravneni, odjeto_jizd) 
                   VALUES (NULL, :jmeno, :prijmeni, :datum_narozeni, :tel_cislo, :email, :heslo,:skupina_opravneni,
                   0)
                   ";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":jmeno", $zak->jmeno);
        $sql->bindParam(":prijmeni", $zak->prijmeni);
        $sql->bindParam(":datum_narozeni", $zak->datum_narozeni);
        $sql->bindParam(":tel_cislo", $zak->tel_cislo);
        $sql->bindParam(":email", $zak->email);
        $sql->bindParam(":heslo", $zak->heslo);
        $sql->bindParam(":skupina_opravneni", $zak->skupina_opravneni);

        if($sql->execute())
        {
            return $this->spojeni->lastInsertId(); //vrátí true, metoda lastInsertId vrací id právě vloženého záznamu
        }
        else
        {
            return false;
        }
    }

    public function smazZaka($id_zaka)
    {
        $dotaz= "DELETE FROM zaci1 WHERE id_zaka= :id_zaka";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zaka", $id_zaka);

        $sql->execute();
    }

    public function prictiJizdu($id_zak)
    {
        $dotaz = "UPDATE zaci1 SET odjeto_jizd = odjeto_jizd + 1 WHERE id_zaka = :id_zak";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zak", $id_zak);

        $sql->execute();
    }

    public function  editujOsUdajeZaka($zak)
    {
        $dotaz = "UPDATE zaci1 SET jmeno= :jmeno, prijmeni= :prijmeni, tel_cislo= :tel_cislo, 
                 email= :email  WHERE id_zaka= :id_zaka";

        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":jmeno", $zak->jmeno);
        $sql->bindParam(":prijmeni", $zak->prijmeni);
        $sql->bindParam(":tel_cislo", $zak->tel_cislo);
        $sql->bindParam(":email", $zak->email);
        $sql->bindParam("id_zaka", $_SESSION["id_zaka"]);
        $sql->execute();
    }

    public function zmenHeslo($heslo)
    {
        $dotaz = "UPDATE zaci1 SET heslo = :heslo WHERE id_zaka = :id_zaka";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":heslo", $heslo);
        $sql->bindParam(":id_zaka", $_SESSION["id_zaka"]);
        $sql->execute();
    }

    public function vyberHeslo($heslo) :bool
    {
        $dotaz = "SELECT heslo FROM zaci1 WHERE id_zaka = :id_zaka";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":id_zaka", $_SESSION["id_zaka"]);
        $sql->execute();
        $sql->setFetchMode(PDO::FETCH_CLASS, "Zak");
        $zak = $sql->fetch();
        if(password_verify($heslo,$zak->heslo))
        {
            return true;
        }
        else
        {
            return false;
        }
    }

    public function overEmail($email)
    {
        $dotaz = "SELECT COUNT(*) FROM zaci1 WHERE email=:email LIMIT 1";
        $sql = $this->spojeni->prepare($dotaz);
        $sql->bindParam(":email", $email);

        if($sql->execute())
        {
            return true;
        }
        else
        {
            return false;
        }
    }
}